import argparse
from .cli import compile_scss_to_css

def main():
    parser = argparse.ArgumentParser(description="Compile SCSS files to CSS")
    parser.add_argument("-scss", required=True, help="Input SCSS folder")
    parser.add_argument("-css", required=True, help="Output CSS folder")
    args = parser.parse_args()

    compile_scss_to_css(args.scss, args.css)



import os
import subprocess

def compile_scss_to_css(scss_dir, css_dir):
    if not os.path.isdir(scss_dir):
        print(f"❌ SCSS directory '{scss_dir}' not found.")
        return
    if not os.path.exists(css_dir):
        os.makedirs(css_dir)

    for filename in os.listdir(scss_dir):
        if filename.endswith(".scss"):
            input_path = os.path.join(scss_dir, filename)
            output_filename = filename.replace(".scss", ".css")
            output_path = os.path.join(css_dir, output_filename)

            try:
                print(f"🔄 Compiling {filename} → {output_filename}")
                subprocess.run(["sass", input_path, output_path], check=True)
            except subprocess.CalledProcessError:
                print(f"❌ Failed to compile {filename}")

    print("✅ All SCSS files compiled to CSS.\nSay thanks for Kakharov.\nhttps://taplink.cc/qaxxorovc")


from setuptools import setup, find_packages

setup(
    name="scssto",
    version="0.1.0",
    description="Compile all .scss files from a folder into .css",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Axmadjon Qaxxorov",
    author_email="qaxxorovc.work@gmail.com",
    url="https://taplink.cc/qaxxorovc",
    packages=find_packages(),
    install_requires=[],
    entry_points={
        "console_scripts": [
            "scsscompile=scsscompile.__main__:main"
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
